User: ko5tik
Date: 02/02/22 10:28:09
Modified: src/java/xtags/condition And.java ClassIsOfType.java
Condition.java IsClass.java IsMethod.java Not.java
Or.java TagParameterEquals.java
Log:
weed out all references to Documented. only one compile error
on XJavaDoc instantiation.
Aslak, would you please fix it?
I go home and prepare myself to watching USA-Russia
Revision Changes Path
1.2 +91 -91 xdocletgui/src/java/xtags/condition/And.java
Index: And.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/And.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- And.java 25 Jan 2002 00:50:20 -0000 1.1
+++ And.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -35,7 +35,7 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import java.util.Iterator;
@@ -70,18 +70,18 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
+ public boolean eval(XProgramElement xprogramelement) {
boolean result = true;
Iterator conditions = getConditions();
while (conditions.hasNext()) {
Condition condition = (Condition)conditions.next();
- if (!condition.eval(documented)) {
+ if (!condition.eval(xprogramelement)) {
result = false;
break;
}
@@ -70,18 +70,18 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method
1.2 +117 -117 xdocletgui/src/java/xtags/condition/ClassIsOfType.java
Index: ClassIsOfType.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/ClassIsOfType.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- ClassIsOfType.java 25 Jan 2002 00:50:22 -0000 1.1
+++ ClassIsOfType.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -35,7 +35,7 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xjavadoc.XClass;
import xjavadoc.XMethod;
@@ -88,21 +88,21 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
+ public boolean eval(XProgramElement xprogramelement) {
boolean result;
XClass clazz;
- if (documented instanceof XClass) {
- clazz = (XClass)documented;
+ if (xprogramelement instanceof XClass) {
+ clazz = (XClass)xprogramelement;
}
else {
- XMethod method = (XMethod)documented;
+ XMethod method = (XMethod)xprogramelement;
clazz = method.containingClass();
}
if (clazz.subclassOf(_className) ||
@@ -88,21 +88,21 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
clazz.implementsInterface(_className)) {
1.3 +140 -139 xdocletgui/src/java/xtags/condition/Condition.java
Index: Condition.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/Condition.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -w -r1.2 -r1.3
--- Condition.java 27 Jan 2002 18:21:00 -0000 1.2
+++ Condition.java 22 Feb 2002 18:28:09 -0000 1.3
@@ -38,7 +38,7 @@
import java.util.ArrayList;
import java.util.Iterator;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
/**
* Base class for conditions. Inspired by the
@@ -94,14 +94,15 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
+ * @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public abstract boolean eval(Documented documented);
+ public abstract boolean eval(XProgramElement xprogramelement);
/**
1.3 +83 -83 xdocletgui/src/java/xtags/condition/IsClass.java
@@ -94,14 +94,15 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
Index: IsClass.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/IsClass.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -w -r1.2 -r1.3
--- IsClass.java 27 Jan 2002 18:39:21 -0000 1.2
+++ IsClass.java 22 Feb 2002 18:28:09 -0000 1.3
@@ -35,11 +35,11 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xjavadoc.XClass;
/**
- * This condition evaluates to true if a Documented is a class.
+ * This condition evaluates to true if a XProgramElement is a class.
*
* @author Aslak Helles�y
* @created 20. desember 2001
@@ -68,15 +68,15 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
- return (documented instanceof XClass);
+ public boolean eval(XProgramElement xprogramelement) {
+ return (xprogramelement instanceof XClass);
}
}
1.3 +83 -83 xdocletgui/src/java/xtags/condition/IsMethod.java
@@ -68,15 +68,15 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
Index: IsMethod.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/IsMethod.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -w -r1.2 -r1.3
--- IsMethod.java 27 Jan 2002 18:39:21 -0000 1.2
+++ IsMethod.java 22 Feb 2002 18:28:09 -0000 1.3
@@ -35,11 +35,11 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xjavadoc.XMethod;
/**
* This condition evaluates to true if a Documented is a method
*
* @author Aslak Helles�y
* @created 20. desember 2001
@@ -68,15 +68,15 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
- return (documented instanceof XMethod);
+ public boolean eval(XProgramElement xprogramelement) {
+ return (xprogramelement instanceof XMethod);
}
}
1.3 +98 -98 xdocletgui/src/java/xtags/condition/Not.java
@@ -35,11 +35,11 @@
import xjavadoc.XMethod;
/**
- * This condition evaluates to true if a Documented is a method
+ * This condition evaluates to true if a XProgramElement is a method
*
* @author Aslak Helles�y
@@ -68,15 +68,15 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
Index: Not.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/Not.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -w -r1.2 -r1.3
--- Not.java 27 Jan 2002 18:21:00 -0000 1.2
+++ Not.java 22 Feb 2002 18:28:09 -0000 1.3
@@ -35,7 +35,7 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import java.util.Iterator;
@@ -72,14 +72,14 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
+ public boolean eval(XProgramElement xprogramelement) {
if (getConditionCount() > 1) {
@@ -91,7 +91,7 @@
throw new IllegalStateException("You must nest a condition
into <not>");
}
- return !((Condition)getConditions().next()).eval(documented);
+ return !((Condition)getConditions().next()).eval(xprogramelement);
}
}
1.2 +92 -91 xdocletgui/src/java/xtags/condition/Or.java
@@ -72,14 +72,14 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method
Index: Or.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/Or.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- Or.java 25 Jan 2002 00:50:22 -0000 1.1
+++ Or.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -35,7 +35,7 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import java.util.Iterator;
@@ -70,18 +70,19 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
+ * @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
+ public boolean eval(XProgramElement xprogramelement) {
boolean result = false;
Iterator conditions = getConditions();
while (conditions.hasNext()) {
Condition condition = (Condition)conditions.next();
- if (condition.eval(documented)) {
+ if (condition.eval(xprogramelement)) {
result = true;
break;
}
@@ -70,18 +70,19 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
1.3 +119 -119 xdocletgui/src/java/xtags/condition/TagParameterEquals.java
Index: TagParameterEquals.java
===================================================================
RCS file:
/cvsroot/xdoclet/xdocletgui/src/java/xtags/condition/TagParameterEquals.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -w -r1.2 -r1.3
--- TagParameterEquals.java 27 Jan 2002 18:39:00 -0000 1.2
+++ TagParameterEquals.java 22 Feb 2002 18:28:09 -0000 1.3
@@ -35,12 +35,12 @@
*/
package xtags.condition;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xjavadoc.XClass;
import xjavadoc.XMethod;
/**
* This condition evaluates to true for a given Documented if it has a tag
* parameter with a certain value.
*
* @author Aslak Helles�y
@@ -104,14 +104,14 @@
/**
* @todo move/copy xdoclet's getTagValue() into clazz
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean eval(Documented documented) {
- String actualTagValue = documented.doc().tagValue(_tagName,
_tagParameter);
+ public boolean eval(XProgramElement xprogramelement) {
+ String actualTagValue = xprogramelement.doc().tagValue(_tagName,
_tagParameter);
return _requiredTagValue.equals(actualTagValue);
}
@@ -35,12 +35,12 @@
import xjavadoc.XMethod;
/**
- * This condition evaluates to true for a given Documented if it has a tag
+ * This condition evaluates to true for a given XProgramElement if it has a tag
* parameter with a certain value.
*
@@ -104,14 +104,14 @@
/**
* @todo move/copy xdoclet's getTagValue() into clazz
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
_______________________________________________
Xdoclet-devel mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/xdoclet-devel